@@ -93,34 +93,52 @@ class Service:
             self.set_service_config (['update'])
 
     else:
-        def install (self):
+        def install (self, update = False):
             name = self.name.split ('/')[-1]
+            service_script = '/etc/systemd/system/{}.service'.format (name)
+            if not update and os.path.exists (service_script):
+                raise SystemError ('service {} is already exists. use update command'.format (name))
             user = os.getenv("SUDO_USER") or 'nobody'
             args = sys.argv [1:]
             if args and hasattr (self, args [-1]):
                 args = args [:-1]
 
+            if self.name == 'skitai/smtpda':
+                import skitai
+                serve = os.path.join (os.path.dirname (skitai.__file__), 'scripts', 'commands', 'smtpda.py')
+            else:
+                serve = os.path.abspath (sys.argv [0])
+
             script = SERVICE_TEMPLATE.format (
                 name = name.title (),
                 user = user,
                 executable = sys.executable,
-                serve = os.path.abspath (sys.argv [0]),
-                args = " ".join (args)
+                serve = serve,
+                args = " ".join (['"{}"'.format (each) for each in args])
             )
-            service_script = '/etc/systemd/system/{}.service'.format (name)
-            with open (service_script, 'w') as f:
-                f.write (script)
-            os.chmod (service_script, 0o755)
+            try:
+                with open (service_script, 'w') as f:
+                    f.write (script)
+            except PermissionError:
+                service_script = '{}.service'.format (name)
+                with open (service_script, 'w') as f:
+                    f.write (script)
+                print ('FAILED, move {} to /etc/systemd/system\n'.format (service_script))
 
             os.system ("systemctl daemon-reload")
+            os.system ("systemctl enable {}".format (name))
             print ("service {} installed".format (name))
             print ("  sudo systemctl start {}".format (name))
 
         def remove (self):
-            self.set_service_config (['remove'])
+            name = self.name.split ('/')[-1]
+            service_script = '/etc/systemd/system/{}.service'.format (name)
+            if not os.path.exists (service_script):
+                return
+            os.remove (service_script)
 
         def update (self):
-            self.set_service_config (['update'])
+            self.install (True)
 
     uninstall = remove
 
@@ -134,7 +152,6 @@ Group={user}
 StandardOutput=syslog+console
 StandardError=syslog+console
 Restart=on-failure
-WorkingDirectory=/var/tmp
 ExecStart={executable} {serve} {args}
 ExecStop=/bin/kill -s TERM $MAINPID
 ExecReload=/bin/kill -s HUP $MAINPID
@@ -142,3 +159,4 @@ ExecReload=/bin/kill -s HUP $MAINPID
 [Install]
 WantedBy=multi-user.target
 '''
+
