@@ -13,60 +13,64 @@ class tc:
     OKGREEN = '\033[92m'
     FAIL = '\033[91m'
     GREY = '\033[90m'
-    
+
     BOLD = '\033[1m'
     UNDERLINE = '\033[4m'
     ENDC = '\033[0m'
-    
+
     @classmethod
     def _wrap (cls, s, c):
         return "{}{}{}".format (c, s, cls.ENDC)
-    
+
     @classmethod
     def default (cls, s):
         return s
-    
-    @classmethod
-    def critical (cls, s):
-        return cls._wrap (s, cls.GREY)
 
     @classmethod
-    def fatal (cls, s):
-        return cls._wrap (s, cls.GREY)
+    def bold (cls, s):
+        return cls._wrap (s, cls.BOLD)
 
     @classmethod
-    def info (cls, s):
+    def underline (cls, s):
+        return cls._wrap (s, cls.UNDERLINE)
+    u = underline
+
+    @classmethod
+    def grey (cls, s):
+        return cls._wrap (s, cls.GREY)
+    critical = fatal = grey
+
+    @classmethod
+    def greeen (cls, s):
         return cls._wrap (s, cls.OKGREEN)
-    
+    ok = info = greeen
+
     @classmethod
-    def warn (cls, s):
+    def yellow (cls, s):
         return cls._wrap (s, cls.WARNING)
-    
+    warning = warn = yellow
+
     @classmethod
-    def expt (cls, s):
+    def magenta (cls, s):
         return cls._wrap (s, cls.MAGENTA)
-    
+    expt = magenta
+
     @classmethod
-    def fail (cls, s):
+    def cyan (cls, s):
         return cls._wrap (s, cls.CYAN)
-    
+    debug = secondary = fail = cyan
+
     @classmethod
-    def error (cls, s):
+    def red (cls, s):
         return cls._wrap (s, cls.FAIL)
-    
+    error = red
+
     @classmethod
-    def debug (cls, s):
+    def white (cls, s):
         return cls._wrap (s, cls.WHITE)
-            
+    echo = white
+
     @classmethod
-    def echo (cls, s):
-        return cls._wrap (s, cls.WHITE)
-    
-    @classmethod
-    def primary (cls, s):
+    def blue (cls, s):
         return cls._wrap (s, cls.OKBLUE)
-    
-    @classmethod
-    def secondary (cls, s): 
-        return cls._wrap (s, cls.CYAN)
-    
\ No newline at end of file
+    primary = blue
